# -*- coding: utf-8 -*-

"""
####################################################################
#                                                                  #
#                           AWI Basemap                            #
#                   PROCESS GSHHG COASTLINE DATA                   #
#                                                                  #
####################################################################

This script is processing the Global Self-consistent Hierarchical
High-resolution Geography (GSHHG) input for the AWI Basemap. All
geometries are fixed (with zero buffer) and the layer is converted
to a GeoPackage.

"""

# ==================================================================
#    SCRIPT INFO
# ==================================================================

__author__ = 'Simon Dreutter'
__version__ = '0.7'
__date__ = '2024-11-18'
__email__ = 'simon.dreutter@awi.de'
__status__ = 'Development'

# ==================================================================
#    IMPORT
# ==================================================================

# import AWI Basemap configuration
from config import *

# ==================================================================
#    PROCESS
# ==================================================================

# layer names
gshhg_in_name = GSHHG_IN.stem
gshhg_world_name = GSHHG_WORLD.stem

# heading
print()
print('====================================================================')
print(f'{"COASTLINES / GSHHG":^68}')

msg = 'Fixing GSHHG geometries...'
cmd = (f'ogr2ogr'
       f' {GSHHG_WORLD} {GSHHG_IN}'
       f' -dialect sqlite'
       f' -sql "SELECT ST_Union(ST_Buffer(geometry, 0.0)) AS geom FROM \"{gshhg_in_name}\"" -nln "{gshhg_world_name}" -f "GPKG"')
run(msg, cmd)
