# -*- coding: utf-8 -*-

"""
####################################################################
#                                                                  #
#                           AWI Basemap                            #
#                             METADATA                             #
#                                                                  #
####################################################################

This script creates a metadata text file for the Basemaps as well as
the TOML configuration files for the WMS.

"""

# ==================================================================
#    SCRIPT INFO
# ==================================================================

__author__ = 'Simon Dreutter'
__version__ = '0.7'
__date__ = '2024-11-18'
__email__ = 'simon.dreutter@awi.de'
__status__ = 'Development'

# ==================================================================
#    IMPORT
# ==================================================================

import textwrap

# import AWI Basemap configuration
from config import *

# ==================================================================
#    METADATA
# ==================================================================

# write metadata to text file
with open(METADATA_FILE, 'w') as f:
    f.write(f'####################################################################\n')
    f.write(f'#                                                                  #\n')
    f.write(f'#{TITLE:^66}#\n')
    f.write(f'#{VERSION:^66}#\n')
    f.write(f'#                                                                  #\n')
    f.write(f'####################################################################\n\n')
    for key, val in METADATA.items():
        if key not in ['VERSION', 'NAME', 'EPSG']:
            f.write(f'{key.replace("_", " ")}\n')
            f.write(f'--------------------------------------------------------------------\n')
            for line in val.splitlines():
                f.write(textwrap.fill(line, width=69, initial_indent='', subsequent_indent='  '))
                f.write('\n')
            f.write(f'\n')

# ==================================================================
#    TOML
# ==================================================================

# ADMIN.LAYER.TOML
# extract urls from sources
urls_list = []
for url in SOURCES.split():
    if url.startswith('http'):
        urls_list.append(url)

# format urls list for toml
urls_list_str = ''
for url in urls_list:
    urls_list_str = f'{urls_list_str}, "{url}"'
urls_list_str = urls_list_str[2:]

# write to file
with open(ADMIN_LAYER_TOML, 'w') as f:
    f.write(f'''
[METADATA]

data_urls.list = [ {urls_list_str} ]
metadata_urls.list = [ "" ]

''')

# ADMIN.SERVICE.TOML
# write to file
with open(ADMIN_SERVICE_TOML, 'w') as f:
    f.write(f'''
abstract = "{ABSTRACT_WMS}"
''')

# OWNER.LAYER.TOML
# format keywords list for toml
keywords_str = ''
for keyword in KEYWORDS:
    keywords_str = f'{keywords_str}, "{keyword}"'
keywords_str = keywords_str[2:]

# write to file
with open(OWNER_LAYER_TOML, 'w') as f:
    f.write(f'''
keywords = [ {keywords_str} ]
''')
