# -*- coding: utf-8 -*-

"""
####################################################################
#                                                                  #
#                           AWI Basemap                            #
#                         COMPUTE CONTOURS                         #
#                                                                  #
####################################################################

This script computes a contour layer from the GEBCO grid.

"""

# ==================================================================
#    SCRIPT INFO
# ==================================================================

__author__ = 'Simon Dreutter'
__version__ = '0.7'
__date__ = '2024-11-18'
__email__ = 'simon.dreutter@awi.de'
__status__ = 'Development'

# ==================================================================
#    IMPORT
# ==================================================================

# import AWI Basemap configuration
from config import *

# ==================================================================
#    PROCESS
# ==================================================================

ELEV_FIELD = 'elevation'  # TODO
CONTOUR_INTERVAL = 50.0  # TODO
CONTOUR_NAME = 'contour'
MIN_LENGTH = 10000  # m
CONTOURS_WORLD_RAW = PATH_RESULT / 'contours_world_raw.gpkg'  # TODO
CONTOURS_WORLD_LENGTH = PATH_RESULT / 'contours_world_length.gpkg'  # TODO
CONTOURS_WORLD_FILTER = PATH_RESULT / 'contours_world_filter.gpkg'  # TODO
CONTOURS_WORLD = PATH_RESULT / 'contours_world.gpkg'  # TODO
CONTOURS_WORLD = PATH_RESULT / 'contours_world_final.gpkg'  # DEBUG

# heading
print()
print('====================================================================')
print(f'{"COMPUTE CONTOURS":^68}')

msg = 'Creating World Contours...'
cmd = (f'gdal_contour'
       f' -b 1'
       f' -a {ELEV_FIELD}'
       f' -i {CONTOUR_INTERVAL}'
       f' -nln "{CONTOUR_NAME}"'
       f' -f "GPKG"'
       f' {GEBCO_IN}'
       f' {CONTOURS_WORLD_RAW}')
# run(msg, cmd) # DEBUG # TODO

msg = 'Write line length...'
cmd = (f'ogr2ogr'
       f' -a_srs  EPSG:{EPSG_WORLD}'
       f' -nln "{CONTOUR_NAME}"'
       f' -nlt LINESTRING'
       f' -f GPKG'
       f' -overwrite'
       f' {CONTOURS_WORLD_RAW} {CONTOURS_WORLD_LENGTH}'
       f' -dialect SQLite'
       f' -sql "SELECT *, CAST(ST_Length(ST_Transform (geom, 3395)) AS int) AS length FROM \'{CONTOUR_NAME}\'"')
run(msg, cmd)

msg = 'Filter contours by length...'
cmd = (f'ogr2ogr'
       f' -a_srs  EPSG:{EPSG_WORLD}'
       f' -nln "{CONTOUR_NAME}"'
       f' -nlt LINESTRING'
       f' -f GPKG'
       f' -overwrite'
       f' {CONTOURS_WORLD_LENGTH} {CONTOURS_WORLD}'
       f' -dialect SQLite'
       f' -sql "SELECT {ELEV_FIELD}, geom FROM \'{CONTOUR_NAME}\' WHERE length > {MIN_LENGTH}"')
run(msg, cmd)

# ogr2ogr {contoursFile} {contoursFile} -update -dialect SQLITE -sql 'UPDATE contour SET geom = ST_Reverse(geom)'"


# TODO: Smooth / Simplyfy, Reverse, PGdump
