# -*- coding: utf-8 -*-

"""
####################################################################
#                                                                  #
#                           AWI Basemap                            #
#            PROCESS GREENLAND ICE MAPPING PROJECT DATA            #
#                                                                  #
####################################################################

This script is processing the Greenland Ice Mapping Project (GIMP)
input for the AWI Basemap. The raster is downsampled for easier data
handling and then polygonized to get a vector dataset.

"""

# ==================================================================
#    SCRIPT INFO
# ==================================================================

__author__ = 'Simon Dreutter'
__version__ = '0.7'
__date__ = '2024-11-18'
__email__ = 'simon.dreutter@awi.de'
__status__ = 'Development'

# ==================================================================
#    IMPORT
# ==================================================================

# import AWI Basemap configuration
from config import *

# ==================================================================
#    PROCESS
# ==================================================================

# resolution for GIMP_RASTER
gimp_res = RESOLUTION_DEG / 2

# layer names
gimp_name = GIMP.stem

# heading
print()
print('====================================================================')
print(f'{"GREENLAND ICE MAPPING PROJECT / GIMP":^68}')

msg = 'Reprojecting and resampling GIMP raster...'
cmd = (f'gdalwarp'
       f' -t_srs EPSG:{EPSG_WORLD}'
       f' -dstnodata 0.0'
       f' -tr {gimp_res} {gimp_res}'
       f' -r near'
       f' -of GTiff'
       f' {GIMP_IN} {GIMP_RASTER}')
run(msg, cmd)

msg = 'Polygonizing GIMP raster...'
cmd = (f'gdal_polygonize'
       f' -b 1'
       f' -of "GPKG"'
       f' {GIMP_RASTER} {GIMP}'
       f' {gimp_name} DN')
run(msg, cmd)

# cleanup
cleanup(GIMP_RASTER)
